##
##  freetype.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         freetype
Summary:      TrueType Font (TTF) Rendering Library
URL:          http://freetype.sourceforge.net/
Vendor:       Free Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Graphics
License:      GPL
Version:      2.13.2
Release:      20230826

#   list of sources
Source0:      http://download-mirror.savannah.gnu.org/releases/freetype/freetype-%{version}.tar.gz
Patch0:       freetype.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, grep
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  zlib, bzip2
PreReq:       zlib, bzip2

%description
    FreeType is a software font engine that is designed to be small,
    efficient, highly customizable and portable while capable of
    producing high-quality output (glyph images). It can be used in
    graphics libraries, display servers, font conversion tools, text
    image generation tools, and many other products as well. FreeType
    is a font service and doesn't provide APIs to perform higher-level
    features, like text layout or graphics processing (e.g. colored text
    rendering, "hollowing", etc..). However, it greatly simplifies these
    tasks by providing a simple, easy to use and uniform interface to
    access the content of font files.

%track
    prog freetype = {
        version   = %{version}
        url       = http://savannah.nongnu.org/download/freetype/
        regex     = freetype-(\d+\.\d+(\.\d+)?)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    ( echo "#!/bin/sh"
      echo "%{l_shtool} install \"\$@\""
    ) >install-sh
    chmod a+x install-sh
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --enable-freetype-config \
        --without-png \
        --without-harfbuzz \
        --with-zlib \
        --with-bzip2 \
        --disable-shared
    %{l_make} %{l_mflags}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

